#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_portal.portlets.spacer import ISpacerPortletSettings
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from pyams_portal import _


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ISpacerPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/spacer.pt', layer=IPyAMSLayer)
class SpacerPortletDefaultRenderer(PortletRenderer):
    """Spacer portlet renderer"""

    label = _("Default spacer")
    weight = 1


@adapter_config(name='double-spacer',
                context=(IPortalContext, IPyAMSLayer, Interface, ISpacerPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/spacer-double.pt', layer=IPyAMSLayer)
class DoubleSpacerPortletDefaultRenderer(PortletRenderer):
    """Double spacer portlet renderer"""

    label = _("Double spacer")
    weight = 2


@adapter_config(name='double-ruler',
                context=(IPortalContext, IPyAMSLayer, Interface, ISpacerPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/spacer-ruler.pt', layer=IPyAMSLayer)
class DoubleRulerSpacerPortletDefaultRenderer(PortletRenderer):
    """Double spacer with ruler portlet renderer"""

    label = _("Double spacer with horizontal ruler")
    weight = 3
